@@ -13,11 +13,11 @@
 #include <librssguard/network-web/webfactory.h>
 #include <librssguard/services/abstract/category.h>
 #include <librssguard/services/abstract/gui/authenticationdetails.h>
+#include <librssguard/services/abstract/gui/httpheadersdetails.h>
 #include <librssguard/services/abstract/serviceroot.h>
 
 #include <QComboBox>
 #include <QDialogButtonBox>
-#include <QFileDialog>
 #include <QGroupBox>
 #include <QNetworkCookie>
 
@@ -27,9 +27,10 @@ FormStandardFeedDetails::FormStandardFeedDetails(ServiceRoot* service_root,
                                                  QWidget* parent)
   : FormFeedDetails(service_root, parent), m_standardFeedDetails(new StandardFeedDetails(this)),
     m_standardFeedExpDetails(new StandardFeedExpDetails(this)), m_authDetails(new AuthenticationDetails(false, this)),
-    m_parentToSelect(parent_to_select), m_urlToProcess(url) {
+    m_headersDetails(new HttpHeadersDetails(this)), m_parentToSelect(parent_to_select), m_urlToProcess(url) {
   insertCustomTab(m_standardFeedDetails, tr("General"), 0);
-  insertCustomTab(m_authDetails, tr("Network"), 2);
+  insertCustomTab(m_headersDetails, tr("HTTP headers"), 2);
+  insertCustomTab(m_authDetails, tr("Auth"), 2);
   insertCustomTab(m_standardFeedExpDetails, tr("Experimental"));
   activateTab(0);
 
@@ -50,19 +51,24 @@ void FormStandardFeedDetails::guessFeed() {
   m_standardFeedDetails->guessFeed(m_standardFeedDetails->sourceType(),
                                    m_standardFeedDetails->m_ui.m_txtSource->textEdit()->toPlainText(),
                                    m_standardFeedDetails->m_ui.m_txtPostProcessScript->textEdit()->toPlainText(),
+                                   qobject_cast<StandardServiceRoot*>(m_serviceRoot),
                                    m_authDetails->authenticationType(),
                                    m_authDetails->username(),
                                    m_authDetails->password(),
-                                   m_serviceRoot->networkProxy());
+                                   StandardFeed::httpHeadersToList(m_headersDetails->httpHeaders()),
+                                   m_serviceRoot->networkProxy(),
+                                   m_standardFeedExpDetails->http2Status());
 }
 
 void FormStandardFeedDetails::guessIconOnly() {
   m_standardFeedDetails->guessIconOnly(m_standardFeedDetails->sourceType(),
                                        m_standardFeedDetails->m_ui.m_txtSource->textEdit()->toPlainText(),
                                        m_standardFeedDetails->m_ui.m_txtPostProcessScript->textEdit()->toPlainText(),
+                                       qobject_cast<StandardServiceRoot*>(m_serviceRoot),
                                        m_authDetails->authenticationType(),
                                        m_authDetails->username(),
                                        m_authDetails->password(),
+                                       StandardFeed::httpHeadersToList(m_headersDetails->httpHeaders()),
                                        m_serviceRoot->networkProxy());
 }
 
@@ -120,13 +126,21 @@ void FormStandardFeedDetails::apply() {
       std_feed->setProtection(m_authDetails->authenticationType());
     }
 
+    if (isChangeAllowed(m_authDetails->findChild<MultiFeedEditCheckBox*>(QSL("m_mcbAuthentication")))) {
+      std_feed->setUsername(m_authDetails->username());
+      std_feed->setPassword(m_authDetails->password());
+    }
+
+    if (isChangeAllowed(m_headersDetails->findChild<MultiFeedEditCheckBox*>(QSL("m_mcbHttpHeaders")))) {
+      std_feed->setHttpHeaders(m_headersDetails->httpHeaders());
+    }
+
     if (isChangeAllowed(m_standardFeedExpDetails->m_ui.m_mcbDontUseRawXml)) {
       std_feed->setDontUseRawXmlSaving(m_standardFeedExpDetails->m_ui.m_cbDontUseRawXml->isChecked());
     }
 
-    if (isChangeAllowed(m_authDetails->findChild<MultiFeedEditCheckBox*>(QSL("m_mcbAuthentication")))) {
-      std_feed->setUsername(m_authDetails->username());
-      std_feed->setPassword(m_authDetails->password());
+    if (isChangeAllowed(m_standardFeedExpDetails->m_ui.m_mcbEnableHttp2)) {
+      std_feed->setHttp2Status(m_standardFeedExpDetails->http2Status());
     }
 
     std_feed->setCreationDate(QDateTime::currentDateTime());
@@ -177,10 +191,15 @@ void FormStandardFeedDetails::loadFeedData() {
     m_authDetails->findChild<MultiFeedEditCheckBox*>(QSL("m_mcbAuthentication"))
       ->addActionWidget(m_authDetails->findChild<QGroupBox*>(QSL("m_gbAuthentication")));
 
+    m_headersDetails->findChild<MultiFeedEditCheckBox*>(QSL("m_mcbHttpHeaders"))
+      ->addActionWidget(m_headersDetails->findChild<QPlainTextEdit*>(QSL("m_txtHttpHeaders")));
+
     m_standardFeedDetails->m_ui.m_btnFetchMetadata->setEnabled(false);
 
     m_standardFeedExpDetails->m_ui.m_mcbDontUseRawXml
       ->addActionWidget(m_standardFeedExpDetails->m_ui.m_cbDontUseRawXml);
+    m_standardFeedExpDetails->m_ui.m_mcbEnableHttp2->addActionWidget(m_standardFeedExpDetails->m_ui.m_lblEnableHttp2);
+    m_standardFeedExpDetails->m_ui.m_mcbEnableHttp2->addActionWidget(m_standardFeedExpDetails->m_ui.m_cmbEnableHttp2);
   }
   else {
     // We hide batch selectors.
@@ -198,6 +217,8 @@ void FormStandardFeedDetails::loadFeedData() {
   m_authDetails->setUsername(std_feed->username());
   m_authDetails->setPassword(std_feed->password());
 
+  m_headersDetails->loadHttpHeaders(std_feed->httpHeaders());
+
   if (m_creatingNew) {
     // auto processed_url = qApp->web()->processFeedUriScheme(m_urlToProcess);
 
@@ -205,7 +226,7 @@ void FormStandardFeedDetails::loadFeedData() {
   }
   else {
     m_standardFeedDetails->setExistingFeed(std_feed);
-
     m_standardFeedExpDetails->m_ui.m_cbDontUseRawXml->setChecked(std_feed->dontUseRawXmlSaving());
+    m_standardFeedExpDetails->setHttp2Status(std_feed->http2Status());
   }
 }
