@@ -36,7 +36,6 @@
 
 #include <QClipboard>
 #include <QCloseEvent>
-#include <QFileDialog>
 #include <QRect>
 #include <QScopedPointer>
 #include <QTimer>
@@ -53,8 +52,7 @@
 
 FormMain::FormMain(QWidget* parent, Qt::WindowFlags f)
   : QMainWindow(parent, f), m_ui(new Ui::FormMain), m_trayMenu(nullptr), m_statusBar(nullptr) {
-  qDebugNN << LOGSEC_GUI
-           << "Creating main application form in thread:" << QUOTE_W_SPACE_DOT(getThreadID());
+  qDebugNN << LOGSEC_GUI << "Creating main application form in thread:" << QUOTE_W_SPACE_DOT(getThreadID());
   // setAttribute(Qt::WA_WindowPropagation, true);
   m_ui->setupUi(this);
   qApp->setMainForm(this);
@@ -96,11 +94,12 @@ FormMain::FormMain(QWidget* parent, Qt::WindowFlags f)
   m_ui->m_menuWebBrowserTabs->addAction(qApp->web()->engineSettingsAction());
 #endif
 
+  setStatusBar(m_statusBar = new StatusBar(this));
+
   // Add these actions to the list of actions of the main window.
   // This allows to use actions via shortcuts
   // even if main menu is not visible.
-  addActions(qApp->userActions());
-  setStatusBar(m_statusBar = new StatusBar(this));
+  addActions(qApp->userAndExtraActions());
 
   // Prepare main window and tabs.
   prepareMenus();
@@ -190,13 +189,14 @@ QList<QAction*> FormMain::allActions() const {
   actions << m_ui->m_actionPlaySelectedArticlesInMediaPlayer;
   actions << m_ui->m_actionOpenSelectedMessagesInternallyNoTab;
   actions << m_ui->m_actionAlternateColorsInLists;
+  actions << m_ui->m_actionPauseFeedFetching;
   actions << m_ui->m_actionMessagePreviewEnabled;
   actions << m_ui->m_actionMarkAllItemsRead;
   actions << m_ui->m_actionMarkSelectedItemsAsRead;
   actions << m_ui->m_actionMarkSelectedItemsAsUnread;
   actions << m_ui->m_actionClearSelectedItems;
+  actions << m_ui->m_actionPurgeSelectedItems;
   actions << m_ui->m_actionClearAllItems;
-  actions << m_ui->m_actionShowOnlyUnreadItems;
   actions << m_ui->m_actionSortFeedsAlphabetically;
   actions << m_ui->m_actionShowTreeBranches;
   actions << m_ui->m_actionAutoExpandItemsWhenSelected;
@@ -273,6 +273,7 @@ void FormMain::prepareMenus() {
   m_ui->m_actionFullscreen->setVisible(false);
 #endif
 
+  /*
   if (QSysInfo::currentCpuArchitecture().contains(QSL("arm"), Qt::CaseSensitivity::CaseInsensitive)) {
     qWarningNN << LOGSEC_GUI << "Disabling native menu bar.";
     m_ui->m_menuBar->setNativeMenuBar(false);
@@ -284,6 +285,7 @@ void FormMain::prepareMenus() {
     m_ui->m_menuBar->setCornerWidget(nullptr);
 #endif
   }
+  */
 }
 
 void FormMain::switchFullscreenMode() {
@@ -463,7 +465,7 @@ void FormMain::updateMessageButtonsAvailability() {
     tabWidget()->feedMessageViewer()->messagesView()->sourceModel()->loadedItem()->kind() == RootItem::Kind::Bin;
 
   m_ui->m_actionDeleteSelectedMessages->setEnabled(atleast_one_message_selected);
-  m_ui->m_actionRestoreSelectedMessages->setEnabled(atleast_one_message_selected && bin_loaded);
+  m_ui->m_actionRestoreSelectedMessages->setEnabled(atleast_one_message_selected);
   m_ui->m_actionMarkSelectedMessagesAsRead->setEnabled(atleast_one_message_selected);
   m_ui->m_actionMarkSelectedMessagesAsUnread->setEnabled(atleast_one_message_selected);
   m_ui->m_actionOpenSelectedMessagesInternallyNoTab->setEnabled(one_message_selected);
@@ -499,6 +501,7 @@ void FormMain::updateFeedButtonsAvailability() {
   m_ui->m_actionBackupDatabaseSettings->setEnabled(!critical_action_running);
   m_ui->m_actionCleanupDatabase->setEnabled(!critical_action_running);
   m_ui->m_actionClearSelectedItems->setEnabled(anything_selected);
+  m_ui->m_actionPurgeSelectedItems->setEnabled(feed_selected || category_selected || service_selected);
   m_ui->m_actionDeleteSelectedItem->setEnabled(!critical_action_running && anything_selected);
   m_ui->m_actionEditSelectedItem->setEnabled(!critical_action_running && anything_selected);
   m_ui->m_actionEditChildFeeds->setEnabled(!critical_action_running && (service_selected || category_selected));
@@ -598,11 +601,14 @@ void FormMain::setupIcons() {
   // Feeds/messages.
   m_ui->m_menuAddItem->setIcon(icon_theme_factory->fromTheme(QSL("list-add")));
   m_ui->m_actionStopRunningItemsUpdate->setIcon(icon_theme_factory->fromTheme(QSL("process-stop")));
+  m_ui->m_actionPauseFeedFetching->setIcon(icon_theme_factory->fromTheme(QSL("media-playback-pause"),
+                                                                         QSL("player_pause")));
   m_ui->m_actionUpdateAllItems->setIcon(icon_theme_factory->fromTheme(QSL("download"), QSL("browser-download")));
   m_ui->m_actionUpdateSelectedItems->setIcon(icon_theme_factory->fromTheme(QSL("download"), QSL("browser-download")));
   m_ui->m_actionUpdateSelectedItemsWithCustomTimers->setIcon(icon_theme_factory->fromTheme(QSL("download"),
                                                                                            QSL("browser-download")));
   m_ui->m_actionClearSelectedItems->setIcon(icon_theme_factory->fromTheme(QSL("mail-mark-junk")));
+  m_ui->m_actionPurgeSelectedItems->setIcon(icon_theme_factory->fromTheme(QSL("edit-clear")));
   m_ui->m_actionClearAllItems->setIcon(icon_theme_factory->fromTheme(QSL("mail-mark-junk")));
   m_ui->m_actionDeleteSelectedItem->setIcon(icon_theme_factory->fromTheme(QSL("list-remove")));
   m_ui->m_actionDeleteSelectedMessages->setIcon(icon_theme_factory->fromTheme(QSL("mail-mark-junk")));
@@ -629,7 +635,6 @@ void FormMain::setupIcons() {
   m_ui->m_actionSelectPreviousMessage->setIcon(icon_theme_factory->fromTheme(QSL("arrow-up")));
   m_ui->m_actionSelectNextUnreadMessage->setIcon(icon_theme_factory->fromTheme(QSL("mail-mark-unread")));
   m_ui->m_actionSortFeedsAlphabetically->setIcon(icon_theme_factory->fromTheme(QSL("format-text-bold")));
-  m_ui->m_actionShowOnlyUnreadItems->setIcon(icon_theme_factory->fromTheme(QSL("mail-mark-unread")));
   m_ui->m_actionExpandCollapseItem->setIcon(icon_theme_factory->fromTheme(QSL("format-indent-more")));
   m_ui->m_actionExpandCollapseItemRecursively->setIcon(icon_theme_factory->fromTheme(QSL("format-indent-more")));
   m_ui->m_actionRestoreSelectedMessages->setIcon(icon_theme_factory->fromTheme(QSL("view-refresh")));
@@ -657,6 +662,7 @@ void FormMain::setupIcons() {
   m_ui->m_actionBrowserScrollUp->setIcon(icon_theme_factory->fromTheme(QSL("arrow-up")));
   m_ui->m_actionBrowserScrollDown->setIcon(icon_theme_factory->fromTheme(QSL("arrow-down")));
   m_ui->m_actionCleanupWebCache->setIcon(icon_theme_factory->fromTheme(QSL("edit-clear")));
+  m_ui->m_actionReloadSkin->setIcon(icon_theme_factory->fromTheme(QSL("view-refresh")));
 
   // Setup icons on TabWidget too.
   m_ui->m_tabWidget->setupIcons();
@@ -711,16 +717,16 @@ void FormMain::loadSize() {
     ->setChecked(settings->value(GROUP(GUI), SETTING(GUI::MessageViewerToolbarsVisible)).toBool());
   m_ui->m_actionSwitchStatusBar->setChecked(settings->value(GROUP(GUI), SETTING(GUI::StatusBarVisible)).toBool());
 
-  // Other startup GUI-related settings.
+  // Other startup GUI-related or misc settings.
   m_ui->m_actionSortFeedsAlphabetically
     ->setChecked(settings->value(GROUP(Feeds), SETTING(Feeds::SortAlphabetically)).toBool());
-  m_ui->m_actionShowOnlyUnreadItems
-    ->setChecked(settings->value(GROUP(Feeds), SETTING(Feeds::ShowOnlyUnreadFeeds)).toBool());
   m_ui->m_actionShowTreeBranches->setChecked(settings->value(GROUP(Feeds), SETTING(Feeds::ShowTreeBranches)).toBool());
   m_ui->m_actionAutoExpandItemsWhenSelected
     ->setChecked(settings->value(GROUP(Feeds), SETTING(Feeds::AutoExpandOnSelection)).toBool());
   m_ui->m_actionAlternateColorsInLists
     ->setChecked(settings->value(GROUP(GUI), SETTING(GUI::AlternateRowColorsInLists)).toBool());
+  m_ui->m_actionPauseFeedFetching
+    ->setChecked(settings->value(GROUP(Feeds), SETTING(Feeds::PauseFeedFetching)).toBool());
 }
 
 void FormMain::saveSize() {
@@ -786,6 +792,8 @@ void FormMain::createConnections() {
   m_ui->m_menuTools->removeAction(m_ui->m_actionCleanupWebCache);
 #endif
 
+  connect(m_ui->m_actionReloadSkin, &QAction::triggered, qApp, &Application::reloadCurrentSkin);
+
   // Menu "Help" connections.
   connect(m_ui->m_actionAboutGuard, &QAction::triggered, this, [this]() {
     FormAbout(false, this).exec();
@@ -921,6 +929,10 @@ void FormMain::createConnections() {
           &QAction::triggered,
           tabWidget()->feedMessageViewer()->feedsView(),
           &FeedsView::clearSelectedItems);
+  connect(m_ui->m_actionPurgeSelectedItems,
+          &QAction::triggered,
+          tabWidget()->feedMessageViewer()->feedsView(),
+          &FeedsView::purgeSelectedFeeds);
   connect(m_ui->m_actionClearAllItems,
           &QAction::triggered,
           tabWidget()->feedMessageViewer()->feedsView(),
@@ -1007,10 +1019,6 @@ void FormMain::createConnections() {
           &QAction::triggered,
           tabWidget()->feedMessageViewer(),
           &FeedMessageViewer::switchMessageSplitterOrientation);
-  connect(m_ui->m_actionShowOnlyUnreadItems,
-          &QAction::toggled,
-          tabWidget()->feedMessageViewer(),
-          &FeedMessageViewer::toggleShowOnlyUnreadFeeds);
   connect(m_ui->m_actionSortFeedsAlphabetically,
           &QAction::toggled,
           tabWidget()->feedMessageViewer()->feedsView(),
@@ -1027,6 +1035,7 @@ void FormMain::createConnections() {
           &QAction::toggled,
           tabWidget()->feedMessageViewer(),
           &FeedMessageViewer::alternateRowColorsInLists);
+  connect(m_ui->m_actionPauseFeedFetching, &QAction::toggled, qApp->feedReader(), &FeedReader::pauseUnpaseFeedFetching);
   connect(m_ui->m_actionRestoreSelectedMessages,
           &QAction::triggered,
           tabWidget()->feedMessageViewer()->messagesView(),
