@@ -98,7 +98,7 @@ void MessagesView::restoreHeaderState(const QByteArray& dta) {
   int saved_header_count = obj[QSL("header_count")].toInt();
 
   if (saved_header_count < header()->count()) {
-    qWarningNN << LOGSEC_GUI << "Detected invalid state for list view.";
+    qWarningNN << LOGSEC_GUI << "Detected invalid state for article list.";
     return;
   }
 
@@ -474,6 +474,11 @@ void MessagesView::mousePressEvent(QMouseEvent* event) {
             emit currentMessageChanged(m_sourceModel->messageAt(mapped_index.row()), m_sourceModel->loadedItem());
           }
         }
+        else if (mapped_index.column() == MSG_DB_READ_INDEX) {
+          if (m_sourceModel->switchMessageReadUnread(mapped_index.row())) {
+            emit currentMessageChanged(m_sourceModel->messageAt(mapped_index.row()), m_sourceModel->loadedItem());
+          }
+        }
       }
 
       break;
@@ -582,19 +587,30 @@ void MessagesView::loadItem(RootItem* item) {
   sort(col, ord, false, true, false, true);
   m_sourceModel->loadMessages(item);
 
-  /*
-  if (item->kind() == RootItem::Kind::Feed) {
-    if (item->toFeed()->isRtl()) {
-      setLayoutDirection(Qt::LayoutDirection::RightToLeft);
+  bool switch_entire_rtl_list =
+    qApp->settings()->value(GROUP(Messages), SETTING(Messages::SwitchArticleListRtl)).toBool();
+
+  if (switch_entire_rtl_list && item != nullptr) {
+    if (item->kind() == RootItem::Kind::Feed) {
+      auto* fd = item->toFeed();
+      setLayoutDirection((fd->rtlBehavior() == RtlBehavior::Everywhere ||
+                          fd->rtlBehavior() == RtlBehavior::EverywhereExceptFeedList)
+                           ? Qt::LayoutDirection::RightToLeft
+                           : Qt::LayoutDirection::LayoutDirectionAuto);
     }
     else {
-      setLayoutDirection(Qt::LayoutDirection::LeftToRight);
+      auto fds = item->getSubTreeFeeds();
+      bool all_feeds_rtl = !fds.isEmpty() && std::all_of(fds.begin(), fds.end(), [](Feed* fd) {
+        return fd->rtlBehavior() == RtlBehavior::Everywhere ||
+               fd->rtlBehavior() == RtlBehavior::EverywhereExceptFeedList;
+      });
+
+      setLayoutDirection(all_feeds_rtl ? Qt::LayoutDirection::RightToLeft : Qt::LayoutDirection::LayoutDirectionAuto);
     }
   }
   else {
-    setLayoutDirection(Qt::LayoutDirection::LeftToRight);
+    setLayoutDirection(Qt::LayoutDirection::LayoutDirectionAuto);
   }
-  */
 
   // Messages are loaded, make sure that previously
   // active message is not shown in browser.
@@ -855,10 +871,10 @@ void MessagesView::searchMessages(SearchLineEdit::SearchMode mode,
 
   m_proxyModel->setFilterCaseSensitivity(sensitivity);
 
-  MessagesToolBar::SearchFields where_search = MessagesToolBar::SearchFields(custom_criteria);
+  BaseToolBar::SearchFields where_search = BaseToolBar::SearchFields(custom_criteria);
 
-  m_proxyModel->setFilterKeyColumn(where_search == MessagesToolBar::SearchFields::SearchTitleOnly ? MSG_DB_TITLE_INDEX
-                                                                                                  : -1);
+  m_proxyModel->setFilterKeyColumn(where_search == BaseToolBar::SearchFields::SearchTitleOnly ? MSG_DB_TITLE_INDEX
+                                                                                              : -1);
 
   if (selectionModel()->selectedRows().isEmpty()) {
     emit currentMessageRemoved(m_sourceModel->loadedItem());
